@@ -11,7 +11,7 @@ import bokeh.io as bkio
 from bokeh.layouts import gridplot
 from bokeh.plotting import Figure
 
-__version__ = "0.6.2"
+__version__ = "0.6.3"
 
 # we don't run a comprehensive test suite and mostly in notebooks,
 # so show warnings all the time.
@@ -195,7 +195,9 @@ def cli():
     subparsers.required = True
 
     # add reporting modules
-    modules = ['demo', 'bcfstats', 'mapula', 'nextclade', 'fastcat', 'simple']
+    modules = [
+        'demo', 'bcfstats', 'mapula', 'nextclade',
+        'fastcat', 'simple', 'depthcoverage']
     for module in modules:
         mod = importlib.import_module('aplanat.components.{}'.format(module))
         p = subparsers.add_parser(module, parents=[mod.argparser()])
